==> kdevelop-4.5.80.tar.xz: kdevelop-4.5.80/projectmanagers/cmake/kdevcmakedocumentation.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=CMake Documentation
Name[bs]=CMake Dokumentacija
Name[ca]=Documentació del CMake
Name[ca@valencia]=Documentació del CMake
Name[cs]=Dokumentace CMake
Name[da]=CMake-dokumentation
Name[de]=CMake-Dokumentation
Name[el]=Τεκμηρίωση CMake
Name[en_GB]=CMake Documentation
Name[es]=Documentación de CMake
Name[et]=CMake'i dokumentatsioon
Name[fi]=CMake-dokumentaatio
Name[fr]=Documentation de CMake
Name[ga]=Doiciméadú CMake
Name[gl]=Documentación de CMake
Name[hu]=CMake dokumentáció
Name[it]=Documentazione CMake
Name[ja]=CMake ドキュメンテーション
Name[kk]=CMake құжаттамасы
Name[km]=ឯកសារ​ CMake
Name[nb]=CMake-dokumentasjon
Name[nds]=CMake-Dokmentatschoon
Name[nl]=CMake-documentatie
Name[pl]=Dokumentacja CMake
Name[pt]=Documentação do CMake
Name[pt_BR]=Documentação do CMake
Name[ru]=Документация CMake
Name[sk]=Dokumentácia CMake
Name[sl]=Dokumentacija za CMake
Name[sv]=CMake-dokumentation
Name[tr]=CMake Belgelendirmesi
Name[ug]=CMake پۈتۈكى(قوللانمىسى)
Name[uk]=Документація з CMake
Name[x-test]=xxCMake Documentationxx
Name[zh_CN]=CMake 文档
Name[zh_TW]=CMake 文件
GenericName=Documentation Support
GenericName[bs]=Podrška za dokumentaciju
GenericName[ca]=Implementació de la documentació
GenericName[ca@valencia]=Implementació de la documentació
GenericName[cs]=Podpora dokumentace
GenericName[da]=Dokumentationsunderstøttelse
GenericName[de]=Dokumentationsunterstützung
GenericName[el]=Υποστήριξη τεκμηρίωσης
GenericName[en_GB]=Documentation Support
GenericName[es]=Implementación de la documentación
GenericName[et]=Dokumentatsiooni toetus
GenericName[fi]=Dokumentaatiotuki
GenericName[fr]=Prise en charge de la documentation
GenericName[ga]=Tacaíocht Doiciméadaithe
GenericName[gl]=Soporte de documentación
GenericName[hu]=Dokumentáció támogatás
GenericName[it]=Supporto documentazione
GenericName[kk]=Құжаттаманы біріктіру
GenericName[km]=គាំទ្រ​ឯកសារ
GenericName[nb]=Dokumentasjonsstøtte
GenericName[nds]=Dokmentatschoon-Ünnerstütten
GenericName[nl]=Documentatie-ondersteuning
GenericName[pl]=Obsługa dokumentacji
GenericName[pt]=Suporte à Documentação
GenericName[pt_BR]=Suporte à Documentação
GenericName[ru]=Поддержка документации
GenericName[sk]=Podpora dokumentácie
GenericName[sl]=Podpora za dokumentacijo
GenericName[sv]=Dokumentationsstöd
GenericName[tr]=Belgelendirme Desteği
GenericName[ug]=پۈتۈك قوللىشى
GenericName[uk]=Підтримка роботи з документацією
GenericName[x-test]=xxDocumentation Supportxx
GenericName[zh_CN]=文档支持
GenericName[zh_TW]=文件支援
Comment=Allows KDevelop to provide CMake documentation
Comment[bs]=Dopišta KDevelopu da obezbjedi CMake dokumentaciju
Comment[ca]=Permet a KDevelop proporcionar informació de CMake
Comment[ca@valencia]=Permet a KDevelop proporcionar informació de CMake
Comment[cs]=Umožňuje KDevelop poskytovat dokumentaci CMake
Comment[da]=Lader KDevelop tilbyde CMake-dokumentation
Comment[de]=Ermöglicht das Bereitstellen von Dokumentation für CMake
Comment[el]=Επιτρέπει στο KDevelop να παρέχει τεκμηρίωση CMake
Comment[en_GB]=Allows KDevelop to provide CMake documentation
Comment[es]=Permite que KDevelop proporcione documentación de CMake
Comment[et]=Võimaldab KDevelopil pakkuda CMake'i dokumentatsiooni
Comment[fi]=Sallii KDevelop-ohjelman tarjota CMake-dokumentaation
Comment[fr]=Permet à KDevelop de fournir la documentation de CMake
Comment[gl]=Permítelle a KDevelop fornecer documentación de CMake
Comment[hu]=Lehetővé teszi a KDevelop számára a CMake dokumentáció biztosítását
Comment[it]=Permette a KDevelop di fornire la documentazione a CMake
Comment[kk]=KDevelop-та CMake құжаттамасын көрсету мүмкіндігі
Comment[nb]=Gjør at KDevelop kan lage CMake-dokumentasjon
Comment[nds]=Mit KDevelop Dokmentatschoon för CMake praatstellen
Comment[nl]=Staat KDevelop toe om CMake-documentatie te leveren
Comment[pl]=Pozwala na dostęp z KDevelopa do dokumentacji CMake
Comment[pt]=Permite ao KDevelop fornecer a documentação do CMake
Comment[pt_BR]=Permite ao KDevelop fornecer documentação do CMake
Comment[ru]=Позволяет создавать документацию CMake в KDevelop
Comment[sk]=Povolí KDevelopu poskytnúť dokumentáciu CMake
Comment[sl]=Omogoča, da KDevelop prikaže dokumentacijo za CMake
Comment[sv]=Låter KDevelop tillhandahålla CMake-dokumentation
Comment[tr]=KDevelop uygulamasına CMake belgelendirmesi sağlar
Comment[ug]=KDevelop نىڭ CMake پۈتۈكلىرىنى تەمىنلىشىگە ئىجازەت
Comment[uk]=Надає змогу KDevelop показувати документацію CMake
Comment[x-test]=xxAllows KDevelop to provide CMake documentationxx
Comment[zh_CN]=允许 KDevelop 提供 CMake 文档
Comment[zh_TW]=允許 KDevelop 提供 CMake 文件
Icon=cmake
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcmakedocumentation
X-KDE-PluginInfo-Author=Aleix Pol
X-KDE-PluginInfo-Email=aleixpol@kde.org
X-KDE-PluginInfo-Name=KDevCMakeDocumentation
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Documentation
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Language=CMake
X-KDevelop-Interfaces=org.kdevelop.IDocumentationProvider,org.kdevelop.ICMakeDocumentation
X-KDevelop-SupportedMimeTypes=text/x-cmake
X-KDevelop-Mode=GUI

==> kdevelop-4.5.90.tar.xz: kdevelop-4.5.90/projectmanagers/cmake/kdevcmakedocumentation.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=CMake Documentation
Name[bs]=CMake Dokumentacija
Name[ca]=Documentació del CMake
Name[ca@valencia]=Documentació del CMake
Name[cs]=Dokumentace CMake
Name[da]=CMake-dokumentation
Name[de]=CMake-Dokumentation
Name[el]=Τεκμηρίωση CMake
Name[en_GB]=CMake Documentation
Name[es]=Documentación de CMake
Name[et]=CMake'i dokumentatsioon
Name[fi]=CMake-dokumentaatio
Name[fr]=Documentation de CMake
Name[ga]=Doiciméadú CMake
Name[gl]=Documentación de CMake
Name[hu]=CMake dokumentáció
Name[it]=Documentazione CMake
Name[ja]=CMake ドキュメンテーション
Name[kk]=CMake құжаттамасы
Name[km]=ឯកសារ​ CMake
Name[nb]=CMake-dokumentasjon
Name[nds]=CMake-Dokmentatschoon
Name[nl]=CMake-documentatie
Name[pl]=Dokumentacja CMake
Name[pt]=Documentação do CMake
Name[pt_BR]=Documentação do CMake
Name[ru]=Документация CMake
Name[sk]=Dokumentácia CMake
Name[sl]=Dokumentacija za CMake
Name[sv]=CMake-dokumentation
Name[tr]=CMake Belgelendirmesi
Name[ug]=CMake پۈتۈكى(قوللانمىسى)
Name[uk]=Документація з CMake
Name[x-test]=xxCMake Documentationxx
Name[zh_CN]=CMake 文档
Name[zh_TW]=CMake 文件
GenericName=Documentation Support
GenericName[bs]=Podrška za dokumentaciju
GenericName[ca]=Implementació de la documentació
GenericName[ca@valencia]=Implementació de la documentació
GenericName[cs]=Podpora dokumentace
GenericName[da]=Dokumentationsunderstøttelse
GenericName[de]=Dokumentationsunterstützung
GenericName[el]=Υποστήριξη τεκμηρίωσης
GenericName[en_GB]=Documentation Support
GenericName[es]=Implementación de la documentación
GenericName[et]=Dokumentatsiooni toetus
GenericName[fi]=Dokumentaatiotuki
GenericName[fr]=Prise en charge de la documentation
GenericName[ga]=Tacaíocht Doiciméadaithe
GenericName[gl]=Soporte de documentación
GenericName[hu]=Dokumentáció támogatás
GenericName[it]=Supporto documentazione
GenericName[kk]=Құжаттаманы біріктіру
GenericName[km]=គាំទ្រ​ឯកសារ
GenericName[nb]=Dokumentasjonsstøtte
GenericName[nds]=Dokmentatschoon-Ünnerstütten
GenericName[nl]=Documentatie-ondersteuning
GenericName[pl]=Obsługa dokumentacji
GenericName[pt]=Suporte à Documentação
GenericName[pt_BR]=Suporte à Documentação
GenericName[ru]=Поддержка документации
GenericName[sk]=Podpora dokumentácie
GenericName[sl]=Podpora za dokumentacijo
GenericName[sv]=Dokumentationsstöd
GenericName[tr]=Belgelendirme Desteği
GenericName[ug]=پۈتۈك قوللىشى
GenericName[uk]=Підтримка роботи з документацією
GenericName[x-test]=xxDocumentation Supportxx
GenericName[zh_CN]=文档支持
GenericName[zh_TW]=文件支援
Comment=Allows KDevelop to provide CMake documentation
Comment[bs]=Dopišta KDevelopu da obezbjedi CMake dokumentaciju
Comment[ca]=Permet a KDevelop proporcionar documentació de CMake
Comment[ca@valencia]=Permet a KDevelop proporcionar informació de CMake
Comment[cs]=Umožňuje KDevelop poskytovat dokumentaci CMake
Comment[da]=Lader KDevelop tilbyde CMake-dokumentation
Comment[de]=Ermöglicht das Bereitstellen von Dokumentation für CMake
Comment[el]=Επιτρέπει στο KDevelop να παρέχει τεκμηρίωση CMake
Comment[en_GB]=Allows KDevelop to provide CMake documentation
Comment[es]=Permite que KDevelop proporcione documentación de CMake
Comment[et]=Võimaldab KDevelopil pakkuda CMake'i dokumentatsiooni
Comment[fi]=Sallii KDevelop-ohjelman tarjota CMake-dokumentaation
Comment[fr]=Permet à KDevelop de fournir la documentation de CMake
Comment[gl]=Permítelle a KDevelop fornecer documentación de CMake
Comment[hu]=Lehetővé teszi a KDevelop számára a CMake dokumentáció biztosítását
Comment[it]=Permette a KDevelop di fornire la documentazione a CMake
Comment[kk]=KDevelop-та CMake құжаттамасын көрсету мүмкіндігі
Comment[nb]=Gjør at KDevelop kan lage CMake-dokumentasjon
Comment[nds]=Mit KDevelop Dokmentatschoon för CMake praatstellen
Comment[nl]=Staat KDevelop toe om CMake-documentatie te leveren
Comment[pl]=Pozwala na dostęp z KDevelopa do dokumentacji CMake
Comment[pt]=Permite ao KDevelop fornecer a documentação do CMake
Comment[pt_BR]=Permite ao KDevelop fornecer documentação do CMake
Comment[ru]=Позволяет создавать документацию CMake в KDevelop
Comment[sk]=Povolí KDevelopu poskytnúť dokumentáciu CMake
Comment[sl]=Omogoča, da KDevelop prikaže dokumentacijo za CMake
Comment[sv]=Låter KDevelop tillhandahålla CMake-dokumentation
Comment[tr]=KDevelop uygulamasına CMake belgelendirmesi sağlar
Comment[ug]=KDevelop نىڭ CMake پۈتۈكلىرىنى تەمىنلىشىگە ئىجازەت
Comment[uk]=Надає змогу KDevelop показувати документацію CMake
Comment[x-test]=xxAllows KDevelop to provide CMake documentationxx
Comment[zh_CN]=允许 KDevelop 提供 CMake 文档
Comment[zh_TW]=允許 KDevelop 提供 CMake 文件
Icon=cmake
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcmakedocumentation
X-KDE-PluginInfo-Author=Aleix Pol
X-KDE-PluginInfo-Email=aleixpol@kde.org
X-KDE-PluginInfo-Name=KDevCMakeDocumentation
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Documentation
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Language=CMake
X-KDevelop-Interfaces=org.kdevelop.IDocumentationProvider,org.kdevelop.ICMakeDocumentation
X-KDevelop-SupportedMimeTypes=text/x-cmake
X-KDevelop-Mode=GUI
